@@ -9,3 +9,8 @@ from .supermetrics_to_azure_sql import SupermetricsToAzureSQL
 from .adls_container_to_container import ADLSContainerToContainer
 from .sharepoint_to_adls import SharepointToADLS
 from .cloud_for_customers_report_to_adls import CloudForCustomersReportToADLS
+
+try:
+    from .sap_to_duckdb import SAPToDuckDB
+except ImportError:
+    pass
