@@ -1,6 +1,7 @@
 import json
 from datetime import timedelta
-from typing import Any, Dict, Literal
+from typing import Any, Dict, List, Literal
+import pandas as pd
 
 from prefect import Task
 from prefect.tasks.secrets import PrefectSecret
@@ -9,8 +10,21 @@ from prefect.utilities.tasks import defaults_from_attrs
 from ..sources import AzureSQL
 from .azure_key_vault import AzureKeyVaultSecret
 
+from ..exceptions import ValidationError
+
 
 def get_credentials(credentials_secret: str, vault_name: str = None):
+    """
+    Get Azure credentials.
+
+    Args:
+        credentials_secret (str): The name of the Azure Key Vault secret containing a dictionary
+        with SQL db credentials (server, db_name, user and password).
+        vault_name (str, optional): The name of the vault from which to obtain the secret. Defaults to None.
+
+    Returns: Credentials
+
+    """
     if not credentials_secret:
         # attempt to read a default for the service principal secret name
         try:
@@ -264,3 +278,74 @@ class AzureSQLDBQuery(Task):
 
         self.logger.info(f"Successfully ran the query.")
         return result
+
+
+class CheckColumnOrder(Task):
+    """
+    Task for checking the order of columns in the loaded DF and in the SQL table into which the data from DF will be loaded.
+    If order is different then DF columns are reordered according to the columns of the SQL table.
+    """
+
+    def __init__(
+        self,
+        table: str = None,
+        if_exists: Literal["fail", "replace", "append", "delete"] = "replace",
+        df: pd.DataFrame = None,
+        credentials_secret: str = None,
+        vault_name: str = None,
+        *args,
+        **kwargs,
+    ):
+        self.credentials_secret = credentials_secret
+        self.vault_name = vault_name
+
+        super().__init__(name="run_check_column_order", *args, **kwargs)
+
+    def df_change_order(
+        self, df: pd.DataFrame = None, sql_column_list: List[str] = None
+    ):
+        df_column_list = list(df.columns)
+        if set(df_column_list) == set(sql_column_list):
+            df_changed = df.loc[:, sql_column_list]
+        else:
+            raise ValidationError(
+                "Detected discrepancies in number of columns or different column names between the CSV file and the SQL table!"
+            )
+
+        return df_changed
+
+    def run(
+        self,
+        table: str = None,
+        if_exists: Literal["fail", "replace", "append", "delete"] = "replace",
+        df: pd.DataFrame = None,
+        credentials_secret: str = None,
+        vault_name: str = None,
+    ):
+        """
+        Run a checking column order
+
+        Args:
+            table (str, optional): SQL table name without schema. Defaults to None.
+            if_exists (Literal, optional): What to do if the table exists. Defaults to "replace".
+            df (pd.DataFrame, optional): Data Frame. Defaults to None.
+            credentials_secret (str, optional): The name of the Azure Key Vault secret containing a dictionary
+            with SQL db credentials (server, db_name, user, and password). Defaults to None.
+            vault_name (str, optional): The name of the vault from which to obtain the secret. Defaults to None.
+        """
+        credentials = get_credentials(credentials_secret, vault_name=vault_name)
+        azure_sql = AzureSQL(credentials=credentials)
+
+        if if_exists not in ["replace", "fail"]:
+            query = f"SELECT COLUMN_NAME FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = '{table}'"
+            result = azure_sql.run(query=query)
+            sql_column_list = [table for row in result for table in row]
+            df_column_list = list(df.columns)
+
+            if sql_column_list != df_column_list:
+                self.logger.warning(
+                    "Detected column order difference between the CSV file and the table. Reordering..."
+                )
+                df = self.df_change_order(df=df, sql_column_list=sql_column_list)
+        else:
+            self.logger.info("The table will be replaced.")
